@@ -3,6 +3,8 @@
 
 import locale
 from io import BytesIO
+from itertools import zip_longest
+
 from lxml import etree
 from zeep.exceptions import Fault
 from PyPDF2 import PdfFileReader, PdfFileWriter
@@ -144,10 +146,10 @@ class CreateDPDShipping(Wizard):
 
         shipment.reference = response.mpsId
         parcels = response.parcelInformation
-        for package, label, parcel in zip(packages, labels, parcels):
+        for package, label, parcel in zip_longest(packages, labels, parcels):
             package.shipping_label = fields.Binary.cast(label.getvalue())
             package.shipping_reference = parcel.parcelLabelNumber
-        Package.save(shipment.root_packages)
+        Package.save(packages)
         shipment.save()
 
         return 'end'
@@ -174,12 +176,12 @@ class CreateDPDShipping(Wizard):
 
     def shipping_party(self, party, address):
         shipping_party = {
-            'name1': address.party_full_name[:50],
+            'name1': address.party_full_name[:35],
             'name2': '',
             'street': ' '.join((address.street or '').splitlines())[:35],
             'country': address.country.code if address.country else '',
             'zipCode': address.zip[:9],
-            'city': address.city[:50],
+            'city': address.city[:35],
             }
         if party.full_name != address.party_full_name:
             shipping_party['name2'] = party.full_name[:35]
